@@ -8,7 +8,7 @@
 #=========================================================#
 package Nile::Base;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 =pod
 
@@ -59,7 +59,7 @@ our @EXPORT_MODULES = (
 		#'MooseX::Declare' => [],
 		#'Nile::Declare' => [],
 		'MooseX::MethodAttributes' => [],
-		'MooseX::ClassAttribute' => [],
+		#'MooseX::ClassAttribute' => [],
 	);
 
 sub import {
